Python: module ichorORM.utils

ichorORM.utils | index

`Copyright (c) 2016-2018 Timothy Savannah
Licensed under the terms of the Lesser GNU Lesser General Public License version 2.1
license can be found at https://raw.githubusercontent.com/kata198/ichorORM/master/LICENSE
utils - Some general utility functions`

Functions
`` |  | convertFilterTypeToOperator(filterType) `convertFilterTypeToOperator - Converts a filter type to a SQL operator @param filterType <str> - A filter type ( likely following "__" such as "fieldName__eq" would be "eq" ) @reurn <str> - Matching SQL operator` isMultiOperator(operator) `isMultiOperator - Check if the given operator takes multiple arguments (like a list, e.x. (1, 2, 3) ) @param operator <str> - An operator (like from convertFilterTypeToOperator) @return <bool>`